========
inliners
========

Overview
--------

Parse a string representing multiple strings.

Installation
------------

To install inliners, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install inliners

License
-------

This project is licensed under the MIT License.

Links
-----

* `Download <https://pypi.org/project/inliners/#files>`_
* `Source <https://pypi.org/project/inliners/>`_

Credits
-------
- Author: Johannes
- Email: johannes-programming@posteo.org

Thank you for using inliners!